@@ -225,6 +225,32 @@ PyDoc_STRVAR(parity_doc,
 Return parity of bitarray `a`.\n\
 `parity(a)` is equivalent to `a.count() % 2` but more efficient.");
 
+
+static PyObject *
+xor_indices(PyObject *module, PyObject *obj)
+{
+    bitarrayobject *a;
+    Py_ssize_t res = 0, nbits, i;
+
+    if (ensure_bitarray(obj) < 0)
+        return NULL;
+
+    a = (bitarrayobject *) obj;
+    nbits = a->nbits;
+    for (i = 1; i < nbits; i++) {
+        if (getbit(a, i))
+            res ^= i;
+    }
+    return PyLong_FromSsize_t(res);
+}
+
+PyDoc_STRVAR(xor_indices_doc,
+"xor_indices(a, /) -> int\n\
+\n\
+Return xor reduced indices of all active bits in bitarray `a`.\n\
+This is essentially equivalent to\n\
+`reduce(operator.xor, [i for i, v in enumerate(a) if v])`.");
+
 /* --------------------------- binary functions ------------------------ */
 
 static PyObject *
@@ -391,26 +417,26 @@ Return tuple with counts of: ~a & ~b, ~a & b, a & ~b, a & b");
 */
 
 static PyObject *
-serialize(PyObject *module, PyObject *a)
+serialize(PyObject *module, PyObject *obj)
 {
+    bitarrayobject *a;
     PyObject *result;
     Py_ssize_t nbytes;
     char *str;
 
-    if (ensure_bitarray(a) < 0)
+    if (ensure_bitarray(obj) < 0)
         return NULL;
 
+    a = (bitarrayobject *) obj;
     nbytes = Py_SIZE(a);
     result = PyBytes_FromStringAndSize(NULL, nbytes + 1);
     if (result == NULL)
         return NULL;
 
     str = PyBytes_AsString(result);
-#define aa  ((bitarrayobject *) a)
-    set_padbits(aa);
-    *str = (IS_BE(aa) ? 0x10 : 0x00) | ((char) PADBITS(aa));
-    memcpy(str + 1, aa->ob_item, (size_t) nbytes);
-#undef aa
+    set_padbits(a);
+    *str = (IS_BE(a) ? 0x10 : 0x00) | ((char) PADBITS(a));
+    memcpy(str + 1, a->ob_item, (size_t) nbytes);
     return result;
 }
 
@@ -1528,6 +1554,7 @@ This function consumes only one bitarray and leaves the remaining stream\n\
 untouched.  Use `sc_encode()` for compressing (encoding).");
 
 #undef BSI
+#undef NSEG
 
 /* ------------------- variable length bitarray format ----------------- */
 
@@ -1666,6 +1693,8 @@ Return variable length binary representation of bitarray.\n\
 This representation is useful for efficiently storing small bitarray\n\
 in a binary stream.  Use `vl_decode()` for decoding.");
 
+#undef LEN_PAD_BITS
+
 /* ----------------------- canonical Huffman decoder ------------------- */
 
 /*
@@ -1837,6 +1866,8 @@ chdi_traverse(chdi_obj *it, visitproc visit, void *arg)
     return 0;
 }
 
+#undef MAXBITS
+
 static PyTypeObject CHDI_Type = {
     PyVarObject_HEAD_INIT(NULL, 0)
     "bitarray.util.canonical_decodeiter",     /* tp_name */
@@ -1878,6 +1909,9 @@ static PyMethodDef module_functions[] = {
                                            METH_VARARGS, ones_doc},
     {"count_n",   (PyCFunction) count_n,   METH_VARARGS, count_n_doc},
     {"parity",    (PyCFunction) parity,    METH_O,       parity_doc},
+    {"xor_indices",
+                  (PyCFunction) xor_indices,
+                                           METH_O,       xor_indices_doc},
     {"count_and", (PyCFunction) count_and, METH_VARARGS, count_and_doc},
     {"count_or",  (PyCFunction) count_or,  METH_VARARGS, count_or_doc},
     {"count_xor", (PyCFunction) count_xor, METH_VARARGS, count_xor_doc},
